# Configuration

Instructions for fresh installs of v.1.10 and later as well as upgrade instructions are now included.

# Flowchart

The following is the flow of actions when initiating a reading with Raspi-Sump

![Flow Chart](https://www.linuxnorth.org/raspi-sump/images/raspi_sump_flowchart.jpg)
